@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Manipulate the position of a note in a scale
 
-our $VERSION = '0.0501';
+our $VERSION = '0.0502';
 
 use Carp;
 use Moo;
@@ -49,33 +49,34 @@ has verbose => (
 sub get_offset {
     my ( $self, %args ) = @_;
 
-    $args{note_format} ||= $self->note_format;
-    $args{offset}      ||= $self->offset;
+    my $note_name   = $args{note_name};
+    my $note_format = $args{note_format} || $self->note_format;
+    my $offset      = $args{offset} || $self->offset;
 
     croak 'note_name, note_format or offset not provided'
-        unless $args{note_name} || $args{note_format} || $args{offset};
+        unless $note_name || $note_format || $offset;
 
     my $rev;  # Going in reverse?
 
-    my $note = Music::Note->new( $args{note_name}, $args{note_format} );
+    my $note = Music::Note->new( $note_name, $note_format );
 
     my $equiv;
     if ( $note->format('isobase') =~ /b/ || $note->format('isobase') =~ /#/ ) {
-        $equiv = Music::Note->new( $args{note_name}, $args{note_format} );
+        $equiv = Music::Note->new( $note_name, $note_format );
         $equiv->en_eq( $note->format('isobase') =~ /b/ ? 'sharp' : 'flat' );
     }
 
     warn sprintf "Given note: %s, ISO: %s/%s, Offset: %d\n",
-        $args{note_name}, $note->format('ISO'), ( $equiv ? $equiv->format('ISO') : '' ), $args{offset}
+        $note_name, $note->format('ISO'), ( $equiv ? $equiv->format('ISO') : '' ), $offset
         if $self->verbose;
 
     my @scale = get_scale_notes( $self->scale_note, $self->scale_name );
     warn "\tScale: @scale\n"
         if $self->verbose;
 
-    if ( $args{offset} < 0 ) {
+    if ( $offset < 0 ) {
         $rev++;
-        $args{offset} = abs $args{offset};
+        $offset = abs $offset;
         @scale  = reverse @scale;
     }
 
@@ -88,14 +89,14 @@ sub get_offset {
     if ( defined $posn ) {
         warn sprintf "\tPosition: %d\n", $posn
             if $self->verbose;
-        $args{offset} += $posn;
+        $offset += $posn;
     }
     else {
         warn "Scale position not defined!\n";
     }
 
     my $octave = $note->octave;
-    my $factor = int( $args{offset} / @scale );
+    my $factor = int( $offset / @scale );
 
     if ( $rev ) {
         $octave -= $factor;
@@ -104,10 +105,10 @@ sub get_offset {
         $octave += $factor;
     }
 
-    $note = Music::Note->new( $scale[ $args{offset} % @scale ] . $octave, 'ISO' );
+    $note = Music::Note->new( $scale[ $offset % @scale ] . $octave, 'ISO' );
 
     warn sprintf "\tNew offset: %d, ISO: %s, Formatted: %s\n",
-        $args{offset}, $note->format('ISO'), $note->format( $args{note_format} )
+        $offset, $note->format('ISO'), $note->format($note_format)
         if $self->verbose;
 
     return $note;
@@ -127,7 +128,7 @@ Music::ScaleNote - Manipulate the position of a note in a scale
 
 =head1 VERSION
 
-version 0.0501
+version 0.0502
 
 =head1 SYNOPSIS
 
@@ -157,17 +158,17 @@ will return C<D#4>.
 
 For offset C<-1>, C<A#3> is returned.
 
-The B<note_format> determines how the B<note_name> is given, and the default is
-C<ISO>.
-
 =head1 ATTRIBUTES
 
 =head2 scale_note
 
-This is the name of the note that starts the given scale.
+This is the name of the note (with no octave) that starts the given
+scale.
 
 Default: C<C>
 
+Examples: C<G#>, C<Eb>
+
 =head2 scale_name
 
 This is the name of the scale to use.
@@ -198,9 +199,11 @@ Default: C<0>
 
 =head1 METHODS
 
-=head2 new()
+=head2 new
 
-  $msn = Music::ScaleNote->new(
+  $msn = Music::ScaleNote->new;  # Use defaults
+
+  $msn = Music::ScaleNote->new(  # Override defaults
     scale_note  => $scale_start_note,
     scale_name  => $scale_name,
     verbose     => $boolean,
@@ -210,19 +213,34 @@ Default: C<0>
 
 Create a new C<Music::ScaleNote> object.
 
-=head2 get_offset()
+=head2 get_offset
 
-  $note = $msn->get_offset(
+  $note = $msn->get_offset( note_name => $note );
+
+  $note = $msn->get_offset(  # Override defaults
     note_name   => $note,
     note_format => $format,
     offset      => $integer,
   );
 
-Return a new L<Music::Note> object based on the given B<note_name>,
-B<note_format> and B<offset>.
+Return a new L<Music::Note> object based on the required B<note_name>,
+and optional B<note_format> and B<offset> parameters.
+
+For formats of C<isobase>, C<ISO> and C<midi>, the B<note_name> can be
+given as a "bare note name" or a note-octave name.  But for the
+C<midinum> format, the B<note_name> must be given as a MIDI note
+number.
+
+Be aware that if the B<note_name> is given as a "bare note" (with no
+octave), and the B<format> is C<ISO>, the octave returned will be C<4>
+by default.  For B<format> of C<midinum> and the B<note_name> being a
+letter, a nonsensical result will be returned.  This mixing up of
+format and note name is B<not> how to use this module.
 
 =head1 SEE ALSO
 
+The F<t/01-methods.t> file in this distribution.
+
 L<Moo>
 
 L<List::Util>
